@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  HxPlayer.cs
  *
@@ -28,6 +29,7 @@
  
 using System;
 using System.Runtime.InteropServices;
+using Mono.Unix;
 
 namespace Helix
 {
@@ -89,10 +91,10 @@ namespace Helix
 			try {
 				if(!HxUnmanaged.ClientPlayerCreate(out token, IntPtr.Zero, 
 					IntPtr.Zero, callbacksRaw))
-					throw new ApplicationException("Couldn't create player");
+					throw new ApplicationException(Catalog.GetString("Couldn't create player"));
 			} catch(NullReferenceException e) {
 				throw new ApplicationException(
-					"Couldn't create player: No HELIX_LIBS?");
+					Catalog.GetString("Couldn't create player: No HELIX_LIBS?"));
 			}
 		}
 
