@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  TrackInfo.cs
  *
@@ -27,6 +28,7 @@
  */
 
 using System;
+using Mono.Unix;
 using Gtk;
  
 namespace Banshee
@@ -120,17 +122,17 @@ namespace Banshee
 	    
 	    public string DisplayArtist { 
 	    	get { return artist == null || artist == String.Empty
-	    		? "Unknown Artist" : artist; } 
+	    		? Catalog.GetString("Unknown Artist") : artist; } 
 	    }
 	    
 	    public string DisplayAlbum { 
 	    	get { return album == null || album == String.Empty 
-	    		? "Unknown Album" : album; } 
+	    		? Catalog.GetString("Unknown Album") : album; } 
 	    }
 	    
 	    public string DisplayTitle { 
 	    	get { return title == null || title == String.Empty
-	    		? "Unknown Title" : title; } 
+	    		? Catalog.GetString("Unknown Title") : title; } 
 	    }    	
 	    
 	    public bool CanSaveToDatabase {
@@ -140,5 +142,10 @@ namespace Banshee
 	    public bool CanPlay {
 	    	get { return canPlay; }
 	    }
+
+		public override string ToString()
+		{
+			return String.Format ("{0} - {1} - {2} ({3})", artist, album, title, uri);
+		}
 	}	
 }
