@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  Core.cs
  *
@@ -193,7 +194,6 @@ namespace Banshee
 					
 					parts = UserRealName.Split(' ');
 					UserFirstName = parts[0].Replace(',', ' ').Trim();
-					UserFirstName += UserFirstName.EndsWith("s") ? "'" : "'s"; 
 				}
 				reader.Close();
 				file.Close();
