@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  Library.cs
  *
@@ -30,6 +31,7 @@ using System;
 using System.Collections;
 using System.Data;
 using System.IO;
+using Mono.Unix;
 using Sql;
 using GConf;
 
@@ -179,7 +181,7 @@ namespace Banshee
 	
 	public class LibrarySource : Source
 	{
-		public LibrarySource() : base("Library", SourceType.Library)
+		public LibrarySource() : base(Catalog.GetString("Library"), SourceType.Library)
 		{
 		
 		}
@@ -263,16 +265,56 @@ namespace Banshee
 			device.Eject();
 			return true;
 		}
+
+		public double DiskUsageFraction
+		{
+			get {
+				return (double)device.VolumeUsed /
+					(double)device.VolumeSize;
+			}
+		}
+
+		private static string BytesToString(ulong bytes)
+		{
+			ulong mb = bytes / (1024 * 1024);
+
+			if (mb > 1024)
+				return String.Format(Catalog.GetString("{0} GB"), mb / 1024);
+			else
+				return String.Format(Catalog.GetString("{0} MB"), mb);
+		}
+
+		public string DiskUsageString
+		{
+			get {
+				// Translators: iPod disk usage. Each {N} is something like "100 MB"
+				return String.Format(
+					Catalog.GetString("{0} of {1}"),
+					BytesToString(device.VolumeUsed),
+					BytesToString(device.VolumeSize));
+			}
+		}
+
+		public string DiskAvailableString
+		{
+			get {
+				// Translators: iPod disk usage. {0} is something like "100 MB"
+				return String.Format(
+					Catalog.GetString("({0} Remaining)"),
+					BytesToString(device.VolumeAvailable));
+			}
+		}
 	}
 	
 	public class AudioCdSource : Source
 	{
-		private AudioDisk disk;
+		private AudioCdDisk disk;
 		
-		public AudioCdSource(AudioDisk disk) : base(disk.DriveName, 
+		public AudioCdSource(AudioCdDisk disk) : base(disk.Title, 
 			SourceType.AudioCd)
 		{
 			this.disk = disk;
+			disk.Updated += OnUpdated;
 			canEject = true;
 		}
 		
@@ -283,7 +325,7 @@ namespace Banshee
 			}
 		}
 		
-		public AudioDisk Disk
+		public AudioCdDisk Disk
 		{
 			get {
 				return disk;
@@ -295,6 +337,13 @@ namespace Banshee
 			disk.Eject();
 			return true;
 		}
+		
+		private void OnUpdated(object o, EventArgs args)
+		{
+			Core.ThreadEnter();
+			Name = disk.Title;
+			Core.ThreadLeave();
+		}
 	}
 
 	public class Playlist 
@@ -337,7 +386,7 @@ namespace Banshee
 		public static string UniqueName
 		{
 			get {
-				return PostfixDuplicate("New Playlist");
+				return PostfixDuplicate(Catalog.GetString("New Playlist"));
 			}
 		}
 		
@@ -356,6 +405,8 @@ namespace Banshee
 					names.Add(ti.Artist);
 				else if(haveAlbum)
 					names.Add(ti.Album);
+				else
+					names.Add("New Playlist");
 			}
 				
 			names.Sort();
