@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  LibraryTrackInfo.cs
  *
@@ -40,6 +41,7 @@ namespace Banshee
 {
 	public class LibraryTrackInfo : TrackInfo
 	{
+		// This is correct; it's used for internal non-user-visible stuff
 		System.Globalization.CultureInfo ci = 
 			new System.Globalization.CultureInfo("en-US");
 	
@@ -310,7 +312,7 @@ namespace Banshee
 			
 			Statement query = new Update("Tracks",
 				"NumberOfPlays", numberOfPlays, 
-				"LastPlayed", lastPlayed) +
+				"LastPlayed", lastPlayed.ToString(ci.DateTimeFormat)) +
 				new Where(new Compare("TrackID", Op.EqualTo, trackId));
 				//new Limit(1);
 
