@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  SearchEntry.cs
  *
@@ -28,6 +29,7 @@
  
 using System;
 using System.Collections;
+using Mono.Unix;
 using Gtk;
 
 namespace Banshee
@@ -165,7 +167,7 @@ namespace Banshee
 				}
 			}	
 			
-			tooltips.SetTip(evBox, "Searching: " + Field, null);
+			tooltips.SetTip(evBox, String.Format(Catalog.GetString("Searching: {0}"), Field), null);
 		}
 		
 		private void ShowMenu(uint time)
@@ -270,7 +272,7 @@ namespace Banshee
 			
 			activeItem.Active = true;
 			
-			tooltips.SetTip(evBox, "Searching: " + Field, null);
+			tooltips.SetTip(evBox, String.Format(Catalog.GetString("Searching: {0}"), Field), null);
 			
 			entry.HasFocus = true;
 			
