@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  SourceView.cs
  *
@@ -28,6 +29,7 @@
  
 using System;
 using System.Collections;
+using Mono.Unix;
 using Gtk;
 using Gdk;
 using Pango;
@@ -92,7 +94,7 @@ namespace Banshee
 			CellRendererPixbuf pixbufRender = new CellRendererPixbuf();
 			CellRendererText textRender = new CellRendererText();
 			
-			col.Title = "Source";
+			col.Title = Catalog.GetString("Source");
 			col.PackStart(pixbufRender, true);
 			col.PackStart(textRender, true);
 			
@@ -144,7 +146,7 @@ namespace Banshee
 		{
 			TreeViewColumn col = new TreeViewColumn();
 			SourceRowRenderer renderer = new SourceRowRenderer();
-			col.Title = "Source";
+			col.Title = Catalog.GetString("Source");
 			col.PackStart(renderer, true);
 			col.SetCellDataFunc(renderer, 
 				new TreeCellDataFunc(SourceCellDataFunc));
@@ -200,7 +202,7 @@ namespace Banshee
 			} catch(NullReferenceException) {}
 			
 			try {
-				foreach(AudioDisk disk in Core.Instance.AudioCdCore.Disks)
+				foreach(AudioCdDisk disk in Core.Instance.AudioCdCore.Disks)
 					store.AppendValues(new AudioCdSource(disk));
 			} catch(NullReferenceException) {}
 			
