@@ -1,3 +1,4 @@
+/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  TrackInfoHeader.cs
  *
@@ -28,6 +29,7 @@
 
 using System;
 using System.Collections;
+using Mono.Unix;
 using Gtk;
 
 namespace Banshee
@@ -139,9 +141,9 @@ namespace Banshee
 		public void SetIdle()
 		{
 			artistLabel.Markup = 
-				"<span weight=\"bold\">Banshee Player</span>";
+				"<span weight=\"bold\">" + Catalog.GetString("Banshee Player") + "</span>";
 			titleLabel.Markup = 
-				"<span size=\"small\">Idle</span>";
+				"<span size=\"small\">" + Catalog.GetString("Idle") + "</span>";
 		}
 	}
 }
